@@ -115,7 +115,7 @@ sub new
     if(defined $defraw) { 
 	$defraw_option = 1;
     }
-
+    
     if (defined $dictfile) {
 	
 	open(DICT, "$dictfile")
@@ -126,12 +126,12 @@ sub new
 	    
 	    if($_=~/^\s*$/) { next; }
 	    
-		my @defs = split (":", $_);
+	    my @defs = split (":", $_);
 	    my $concept = $defs[0]; 
-		$concept =~ s/^\s+//;
-		$concept =~ s/\s+$//;
+	    $concept =~ s/^\s+//;
+	    $concept =~ s/\s+$//;
 	    my $definition = $defs[1];	
-		$dictionary{$concept} = $definition;
+	    $dictionary{$concept} = $definition;
 	}
 	close DICT;
     }
@@ -150,7 +150,7 @@ sub new
 	$length{$terms[1]} = $terms[3]; 
     }
     close INDX;
-
+    
     if(defined $debugfile) { 
 	if(-e $debugfile) {
 	    print "Debug file $debugfile already exists! Overwrite (Y/N)? ";
@@ -162,25 +162,25 @@ sub new
 	
 	open(DEBUG, ">$debugfile") || die "Could not open debug file: $debugfile\n";
     }
-  
-	if (defined $stoplist) {
-
+    
+    if (defined $stoplist) {
+	
 	open(STP, "$stoplist")
 	    or die("Error: cannot open stop list file ($stoplist).\n");
-
+	
 	$stopregex  = "(";
-    while(<STP>) {
-        chomp;
-		if($_ ne ""){
+	while(<STP>) {
+	    chomp;
+	    if($_ ne ""){
         	$_=~s/\///g;
         	$stopregex .= "$_|";
 		}
-    }   
-    chop $stopregex; $stopregex .= ")";
-    close STP;
-
-	}
-
+	}   
+	chop $stopregex; $stopregex .= ")";
+	close STP;
+	
+    }
+    
     return $self;
 }
 
@@ -193,218 +193,220 @@ sub getRelatedness
     
     my $concept1 = shift;
     my $concept2 = shift;
-
-	if(defined $debugfile) {
-    print DEBUG "$concept1<>$concept2\n";
+    
+    if(defined $debugfile) {
+	print DEBUG "$concept1<>$concept2\n";
     }
    
     my $interface = $self->{'interface'};
-        
+    
     my $d1 = "";
     my $d2 = "";
     
     if (!defined $dictfile) {
 	if ($concept1 =~ /C[0-9]+/)
 	{	
-		my $defs1 = $interface->getExtendedDefinition($concept1);
-        if(defined $debugfile) {
-        print DEBUG "DEFINITIONS FOR $concept1: \n";
-        }
-        my $i = 1;
-        foreach my $def (@{$defs1}) {
-        if(defined $debugfile) {
-        print DEBUG "$i. $def\n";
-        $i++;
-        }
-	$def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-        $d1 .= $5 . " ";
-        }
-
-		#if the definition is empty, return -1
-		if ($d1 eq "") 
-		{
-			return -1;
+	    my $defs1 = $interface->getExtendedDefinition($concept1);
+	    if(defined $debugfile) {
+		print DEBUG "DEFINITIONS FOR $concept1: \n";
+	    }
+	    my $i = 1;
+	    foreach my $def (@{$defs1}) {
+		if(defined $debugfile) {
+		    print DEBUG "$i. $def\n";
+		    $i++;
 		}
-    }
-    if($concept2 =~ /C[0-9]+/)
-    {
-        my $defs2 = $interface->getExtendedDefinition($concept2);
-        if(defined $debugfile) {
-        print DEBUG "DEFINITIONS FOR $concept2: \n";
-        }
-        my $i = 1;
-        foreach my $def (@{$defs2}) {
-        if(defined $debugfile) {
-        print DEBUG "$i. $def\n";
-        $i++;
-        }
-        $def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-        $d2 .= $5 . " ";
-        }
+		$def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
+		$d1 .= $5 . " ";
+	    }
 
-		#if the definition is empty, return -1
-		if ($d2 eq "") 
-		{
-			return -1;
-		}
-    }
-    } # end of without --dictfile option 
-
-	if (defined $dictfile)
-	{ 
-		my $defs1;
-		my $defs2;
-		my $term1;
-		my $term2;
-		my $term1_def = "";
-		my $term2_def = "";
-
-		if(defined $debugfile) { print DEBUG "DEFINITIONS FOR CUI 1: $concept1\n"; }
-
-		if($concept1 =~ /^(C[0-9]+)(\#)(.*?)$/)
-		{
-			my $cui1 = $1;
-			$term1 = $3;
-
-			$defs1 = $interface->getExtendedDefinition($cui1);
-			$term1_def = $dictionary{$term1} if (defined $dictionary{$term1});
-
-			my $i = 1;
-			foreach my $extendeddef (@{$defs1}) {
-			if (defined $debugfile) {
-			print DEBUG "$i. $extendeddef\n";
-			$i++;
-			}
-
-			#  seperate definition from the other information 
-			#  sent by the getExtendedDefinition function
-			$extendeddef=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-			my $def = $5;
-			
-			#  store the definition in the string d1
-			$d1 .= $def . " "; 
-			}	   
-
-			$d1 .= $term1_def . " " if $term1_def ne ""; 
-
-			if(defined $debugfile)
-			{
-				print DEBUG "$i. $term1_def\n" if (defined $term1_def);
-			}
-
-			#if the definition is empty, return -1
-			if ($d1 eq "") 
-			{
-				return -1;
-			}
-		}
-		else
-		{
-			if (defined $dictionary{$concept1}) {
-			$d1 = $dictionary{$concept1};
-			if (defined $debugfile) {
-			print DEBUG "$concept1: $d1\n"; }
-			}
-			else{
-			if (defined $debugfile) {
-			print DEBUG "$concept1: not defined\n"; }
-			return -1; }
-		}
-
-		if(defined $debugfile) { print DEBUG "DEFINITIONS FOR CUI 2: $concept2\n"; }
-
-		if($concept2 =~ /^(C[0-9]+)(\#)(.*?)$/)
-		{
-			my $cui2 = $1;
-			$term2 = $3;
-
-			$defs2 = $interface->getExtendedDefinition($cui2);
-			$term2_def = $dictionary{$term2} if (defined $dictionary{$term2});
-
-			my $i = 1;
-			foreach my $extendeddef (@{$defs2}) {
-			if (defined $debugfile) {
-			print DEBUG "$i. $extendeddef\n";
-			$i++;
-			}
-
-			#  seperate definition from the other information 
-			#  sent by the getExtendedDefinition function
-			$extendeddef=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-			my $def = $5;
-			
-			#  store the definition in the string d1
-			$d2 .= $def . " "; 
-			}	   
-
-			$d2 .= $term2_def . " " if $term2_def ne ""; 
-
-			if(defined $debugfile)
-			{
-				print DEBUG "$i. $term2_def\n" if (defined $term2_def);
-			}
-			
-			#if the definition is empty, return -1
-			if ($d2 eq "") 
-			{
-				return -1;
-			}
-		}
-		else
-		{
-			if (defined $dictionary{$concept2}) {
-			$d2 = $dictionary{$concept2};
-			if (defined $debugfile) {
-			print DEBUG "$concept2: $d2\n"; }
-			}
-			else{
-			if (defined $debugfile) {
-			print DEBUG "$concept2: not defined\n"; }
-			return -1; }
-		}
-
-	} #end of defined --dictfile option
-
-	# if --stopword option is set remove stop words
-	if (defined $stoplist) 
+	    #if the definition is empty, return -1
+	    if ($d1 eq "") 
+	    {
+		return -1;
+	    }
+	}
+	if($concept2 =~ /C[0-9]+/)
 	{
-		my @def1 = split(/\s/, $d1);	
-		my @def2 = split(/\s/, $d2);	
-		my @new_def1 = ();
-		my @new_def2 = ();
-		foreach my $w (@def1) {
-		    if (!($w =~ /$stopregex/)) {
-			push (@new_def1, $w);}
+	    my $defs2 = $interface->getExtendedDefinition($concept2);
+	    if(defined $debugfile) {
+		print DEBUG "DEFINITIONS FOR $concept2: \n";
+	    }
+	    my $i = 1;
+	    foreach my $def (@{$defs2}) {
+		if(defined $debugfile) {
+		    print DEBUG "$i. $def\n";
+		    $i++;
 		}
-		foreach my $w (@def2) {
-		    if (!($w =~ /$stopregex/)) {
-			push (@new_def2, $w);}
+		$def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
+		$d2 .= $5 . " ";
+	    }
+	    
+	    #if the definition is empty, return -1
+	    if ($d2 eq "") 
+	    {
+		return -1;
+	    }
+	}
+    } # end of without --dictfile option 
+    
+    if (defined $dictfile)
+    { 
+	my $defs1;
+	my $defs2;
+	my $term1;
+	my $term2;
+	my $term1_def = "";
+	my $term2_def = "";
+	
+	if(defined $debugfile) { print DEBUG "DEFINITIONS FOR CUI 1: $concept1\n"; }
+	
+	if($concept1 =~ /^(C[0-9]+)(\#)(.*?)$/)
+	{
+	    my $cui1 = $1;
+	    $term1 = $3;
+	    
+	    $defs1 = $interface->getExtendedDefinition($cui1);
+	    $term1_def = $dictionary{$term1} if (defined $dictionary{$term1});
+	    
+	    my $i = 1;
+	    foreach my $extendeddef (@{$defs1}) {
+		if (defined $debugfile) {
+		    print DEBUG "$i. $extendeddef\n";
+		    $i++;
 		}
 		
-		$d1 = join (" ", @new_def1);	
-		$d2 = join (" ", @new_def2);	
-	}
+		#  seperate definition from the other information 
+		#  sent by the getExtendedDefinition function
+		$extendeddef=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
+		my $def = $5;
+		
+		#  store the definition in the string d1
+		$d1 .= $def . " "; 
+	    }	   
 	    
-	if(defined $stem) 
-	{
-		my @def_words1 = split(/\s/, $d1);
-		my $stemmed_words1 = Lingua::Stem::En::stem({ -words => \@def_words1, -locale => 'en'});
-		$d1 = join(" ", @{$stemmed_words1});
-
-		my @def_words2 = split(/\s/, $d2);
-		my $stemmed_words2 = Lingua::Stem::En::stem({ -words => \@def_words2, -locale => 'en'});
-		$d2 = join(" ", @{$stemmed_words2});
+	    $d1 .= $term1_def . " " if $term1_def ne ""; 
+	    
+	    if(defined $debugfile)
+	    {
+		print DEBUG "$i. $term1_def\n" if (defined $term1_def);
+	    }
+	    
+	    #if the definition is empty, return -1
+	    if ($d1 eq "") 
+	    {
+		return -1;
+	    }
 	}
-
- #  if the --defraw option is not set clean up the defintions
-    if($defraw_option == 0) {
-    $d1 = lc($d1); $d2 = lc($d2);
-
-    # remove punctuation doesn't contain '<' and '>'    
-    $d1=~s/[\.\,\?\/\'\"\;\:\[\]\{\}\!\@\#\$\%\^\&\*\(\)\-\_\+\-\=]//g;
-    $d2=~s/[\.\,\?\/\'\"\;\:\[\]\{\}\!\@\#\$\%\^\&\*\(\)\-\_\+\-\=]//g;
+	else
+	{
+	    if (defined $dictionary{$concept1}) {
+		$d1 = $dictionary{$concept1};
+		if (defined $debugfile) {
+		    print DEBUG "$concept1: $d1\n"; 
+		}
+	    }
+	    else{
+		if (defined $debugfile) {
+		    print DEBUG "$concept1: not defined\n"; 
+		}
+		return -1; }
+	}
+	
+	if(defined $debugfile) { print DEBUG "DEFINITIONS FOR CUI 2: $concept2\n"; }
+	
+	if($concept2 =~ /^(C[0-9]+)(\#)(.*?)$/)
+	{
+	    my $cui2 = $1;
+	    $term2 = $3;
+	    
+	    $defs2 = $interface->getExtendedDefinition($cui2);
+	    $term2_def = $dictionary{$term2} if (defined $dictionary{$term2});
+	    
+	    my $i = 1;
+	    foreach my $extendeddef (@{$defs2}) {
+		if (defined $debugfile) {
+		    print DEBUG "$i. $extendeddef\n";
+		    $i++;
+		}
+		
+		#  seperate definition from the other information 
+		#  sent by the getExtendedDefinition function
+		$extendeddef=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
+		my $def = $5;
+		
+		#  store the definition in the string d1
+		$d2 .= $def . " "; 
+	    }	   
+	    
+	    $d2 .= $term2_def . " " if $term2_def ne ""; 
+	    
+	    if(defined $debugfile)
+	    {
+		print DEBUG "$i. $term2_def\n" if (defined $term2_def);
+	    }
+	    
+	    #if the definition is empty, return -1
+	    if ($d2 eq "") 
+	    {
+		return -1;
+	    }
+	}
+	else
+	{
+	    if (defined $dictionary{$concept2}) {
+		$d2 = $dictionary{$concept2};
+		if (defined $debugfile) {
+		    print DEBUG "$concept2: $d2\n"; }
+	    }
+	    else{
+		if (defined $debugfile) {
+		    print DEBUG "$concept2: not defined\n"; }
+		return -1; }
+	}
+	
+    } #end of defined --dictfile option
+    
+    # if --stopword option is set remove stop words
+    if (defined $stoplist) 
+    {
+	my @def1 = split(/\s/, $d1);	
+	my @def2 = split(/\s/, $d2);	
+	my @new_def1 = ();
+	my @new_def2 = ();
+	foreach my $w (@def1) {
+	    if (!($w =~ /$stopregex/)) {
+		push (@new_def1, $w);}
+	}
+	foreach my $w (@def2) {
+	    if (!($w =~ /$stopregex/)) {
+		push (@new_def2, $w);}
+	}
+	
+	$d1 = join (" ", @new_def1);	
+	$d2 = join (" ", @new_def2);	
     }
-
+    
+    if(defined $stem) 
+    {
+	my @def_words1 = split(/\s/, $d1);
+	my $stemmed_words1 = Lingua::Stem::En::stem({ -words => \@def_words1, -locale => 'en'});
+	$d1 = join(" ", @{$stemmed_words1});
+	
+	my @def_words2 = split(/\s/, $d2);
+	my $stemmed_words2 = Lingua::Stem::En::stem({ -words => \@def_words2, -locale => 'en'});
+	$d2 = join(" ", @{$stemmed_words2});
+    }
+    
+    #  if the --defraw option is not set clean up the defintions
+    if($defraw_option == 0) {
+	$d1 = lc($d1); $d2 = lc($d2);
+	
+	# remove punctuation doesn't contain '<' and '>'    
+	$d1=~s/[\.\,\?\/\'\"\;\:\[\]\{\}\!\@\#\$\%\^\&\*\(\)\-\_\+\-\=]//g;
+	$d2=~s/[\.\,\?\/\'\"\;\:\[\]\{\}\!\@\#\$\%\^\&\*\(\)\-\_\+\-\=]//g;
+    }
+    
     open(MATX, "<$vectormatrix")
         or die("Error: cannot open file '$vectormatrix' for output index.\n");
     
@@ -412,15 +414,15 @@ sub getRelatedness
     my %vector2 = ();
     my @defs1 = split(" ", $d1);	
     my @defs2 = split(" ", $d2);	
-   
+    
     my $def1_length = 0 ;
-
+    
     foreach my $def_term1 (@defs1)
     {
 	if (defined $index{$def_term1})
 	{
 	    my $index_term = $index{$def_term1};
-        my $p = $position{$index_term};
+	    my $p = $position{$index_term};
 	    my $l = $length{$index_term};
 	    
 	    if (($p==0) and (!defined $l))
@@ -438,7 +440,7 @@ sub getRelatedness
 		    if (defined $debugfile) {
 			print DEBUG "$def_term1: ";
 		    }
-
+		    
 		    chomp($data);
 		    my @word_vector = split (' ', $data);
 		    my $index = shift @word_vector;
@@ -446,27 +448,27 @@ sub getRelatedness
 		    
 		    if ($index_term == $1)
 		    {
-				for (my $z=0; $z<@word_vector; )
-				{
-					$vector1{$word_vector[$z]} += $word_vector[$z+1];
-					$z += 2;
-					
-					if (defined $debugfile) { 
-					if(defined $word_vector[$z]) {
-						print DEBUG "$reverse_index{$word_vector[$z]} ";
-					}
-					} 	
-					
+			for (my $z=0; $z<@word_vector; )
+			{
+			    $vector1{$word_vector[$z]} += $word_vector[$z+1];
+			    $z += 2;
+			    
+			    if (defined $debugfile) { 
+				if(defined $word_vector[$z]) {
+				    print DEBUG "$reverse_index{$word_vector[$z]} ";
 				}
-				
-				if (defined $debugfile) {
-					print DEBUG "\n";
-				} 	
+			    } 	
+			    
+			}
+			
+			if (defined $debugfile) {
+			    print DEBUG "\n";
+			} 	
 		    }
 		    else 
 		    {
-				print STDERR "$def_term1 is not a correct word!\n";
-				exit;
+			print STDERR "$def_term1 is not a correct word!\n";
+			exit;
 		    }
 		}	
 	    }
